//
//  LinkVRTCEngine.h
//  iOS_Zego
//
//  Created by Wing on 2020/8/4.
//  Copyright © 2020 Wing. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "VideoQuality.h"

typedef NS_ENUM(NSInteger, SDKType) {
    SDK_TYPE_LVRTC = 3,
    SDK_TYPE_ZEGO  = 4,
};

typedef NS_ENUM(NSInteger, VideoConfigLevel) {
    Video_Config_180P = 0,
    Video_Config_270P,
    Video_Config_360P,
    Video_Config_540P,
    Video_Config_720P,
    Video_Config_1080P,
};

NS_ASSUME_NONNULL_BEGIN

@protocol RTCProtocol <NSObject>

- (void)initSDK:(NSString *)appId appKey:(NSString *)appKey isTestEnv:(BOOL)isTestEnv isInternationalEnv:(BOOL)isInternationalEnv;
- (void)setLogOpen:(BOOL)isOpen;
// 推流参数配置
- (void)setVideoConfig:(VideoConfigLevel)configLevel;
- (void)loginRoom:(NSString *)uid roomId:(NSString *)roomId isHost:(BOOL)isHost isAudioOnly:(BOOL)isAudioOnly;
- (void)logoutRoom;
- (void)startPreview:(UIView *)view;
- (void)startPublishing;
- (void)startPlayingStream:(NSString *)uid inView:(UIView *)view;
- (void)stopPlayingStream:(NSString *)uid;
// 转换前后置摄像头
- (void)useFrontCamera:(BOOL)isFront;
// 获取连麦SDK的名称
- (NSString *)getSolutionName;
// 获取支持连麦数
- (int)getSupportLine;
// 获取SDK类型 3为自研，4为zego
- (SDKType)getSDKType;
// 设置是否静音推流
- (void)enableMic:(BOOL)isMute;
// 释放引擎
- (void)unInitSDK;
- (int)getMicVolume;
/// sdk版本号
- (NSString *)sdkVersion;
/// 设置推流时数据统计信息回调的频率，回调方法请看 OnPublishQualityUpdate 回调
/// @param seconds 回调频率（1 / sec）
- (void)setPublishQualityMonitorCycle:(int)seconds;
/// 设置拉流时数据统计信息回调的频率，回调方法请看 OnPlayQualityUpate 回调
/// @param seconds 回调频率（1 / sec）
- (void)setPlayQualityMonitorCycle:(int)seconds;
/// 停止发布音视频数据
- (void)stopPublishStream;

/// 设置是否允许 SDK 自动根据设备的方向调整视频的输出方向
/// @param enable 打开和关闭（默认是 YES）
-(void)enableVideoAutoRotation:(BOOL)enable;

/**
 * 设置美颜滤镜级别
 * @param beautyLevel 滤镜美颜级别 取值范围[0,1]，设置-1关闭
 */
- (void)setBeautyLevel:(CGFloat)beautyLevel;
/**
 * 设置滤镜明亮度
 * @param brightLevel 滤镜明亮度 取值范围[0,1]，设置-1关闭
 */
- (void)setBrightLevel:(CGFloat)brightLevel;
/**
 * 设置滤镜饱和度
 * @param toneLevel 滤镜饱和度 取值范围[0,1]，设置-1关闭
 */
- (void)setToneLevel:(CGFloat)toneLevel;

/// 开始采集视频流
- (void)startCapture;
/// 停止采集视频流
- (void)stopCapture;

@end

@protocol RTCCallbackDelegate <NSObject>

- (void)onAddRemoterUser:(NSString *)uid;
- (void)onRemoteLeave:(NSString *)uid;

/**
 * 被踢出房间或断开房间链接
 * @param errorCode 错误码，参见Zego或LinkV错误码
 * @param roomId 房间id
 */
- (void)onRoomDisconnect:(int)errorCode roomId:(NSString *)roomId;

- (void)onRoomConnected:(NSString *)roomId;
- (void)onVideoSizeChanged:(NSString *)uid width:(int)width height:(int)height;
- (void)onPublishStreamQualityUpdate:(NSString *)uid quality:(VideoQuality *)quality;
- (void)onRemoteQualityUpdate:(NSString *)uid quality:(VideoQuality *)quality;

/**
 * 鉴权回调
 * @param errorCode 0表示鉴权成功，其余均为错误，参见Zego或LinkV错误码
 */
- (void)authComplete:(NSInteger)errorCode;

- (void)onPlayStateUpdate:(int)code userId:(nonnull NSString *)userId;
- (void)onPublishStateUpdate:(int)code;

@end

@interface LinkVRTCEngine : NSObject<RTCProtocol>

+ (instancetype)createEngine:(SDKType)type
                       appId:(NSString *)appId
                      appKey:(NSString *)appKey
                   isTestEnv:(BOOL)isTestEnv
          isInternationalEnv:(BOOL)isInternationalEnv
                    delegate:(id<RTCCallbackDelegate>)delegate;

@property (nonatomic, copy, nullable) NSString *roomId;
@property (nonatomic, copy, nullable) NSString *uid;

@end

NS_ASSUME_NONNULL_END
